@@ -1,13 +1,20 @@
 package SWF::Builder::Character::Bitmap::Lossless::GD;
 
 use strict;
+use GD;
+use Carp;
 
 our @ISA = ('SWF::Builder::Character::Bitmap::Lossless');
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub new {
     my ($class, $image) = @_;
 
+    unless (ref($image)) {
+	my $file = $image;
+	$image = GD::Image->new($file) or croak "Can't create GD::Image object for $file";
+    }
+
     my ($width, $height) = $image->getBounds;
     my $tp_i = $image->transparent;
     bless {
